@@ -4,7 +4,6 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "config-kitinerary.h"
 #include "testhelpers.h"
 
 #include <KItinerary/ExtractorDocumentNode>
@@ -58,11 +57,7 @@ private Q_SLOTS:
         QTest::newRow("text/plain") << s(SOURCE_DIR "/scriptenginedata/plain-text.txt") << s(SOURCE_DIR "/scriptenginedata/plain-text.txt.json");
         QTest::newRow("pkpass") << s(SOURCE_DIR "/pkpassdata/swiss.pkpass") << s(SOURCE_DIR "/scriptenginedata/swiss.pkpass.json");
         QTest::newRow("IATA BCBP PDF") << s(SOURCE_DIR "/extractordata/synthetic/iata-bcbp-demo.pdf")
-#if HAVE_ZXING
             << s(SOURCE_DIR "/scriptenginedata/iata-bcbp-demo.pdf.json");
-#else
-            << s(SOURCE_DIR "/scriptenginedata/iata-bcbp-demo.pdf-no-zxing.json");
-#endif
 #if KCALENDARCORE_VERSION >= QT_VERSION_CHECK(5, 103, 0)
         QTest::newRow("ical") << s(SOURCE_DIR "/extractordata/ical/eventreservation.ics") << s(SOURCE_DIR "/scriptenginedata/eventreservation.ics.json");
 #endif
