@@ -98,6 +98,7 @@ class KITINERARY_EXPORT PdfDocument : public QObject
     Q_PROPERTY(QDateTime modificationTime READ modificationTime CONSTANT)
     Q_PROPERTY(QString title READ title CONSTANT)
     Q_PROPERTY(QString producer READ producer CONSTANT)
+    Q_PROPERTY(QString creator READ creator CONSTANT)
 
 public:
     explicit PdfDocument(QObject *parent = nullptr);
@@ -124,6 +125,8 @@ public:
     QString title() const;
     /** The document producer. */
     QString producer() const;
+    /** The document creator. */
+    QString creator() const;
 
     /** Creates a PdfDocument from the given raw data.
      *  @returns @c nullptr if loading fails or Poppler was not found.
